# standard imports
import uuid

# local imports
from .hex import HexDir
from .hex import default_formatter


class UUIDDir(HexDir):

    def __init__(self, root_path, levels=2, prefix_length=0, formatter=default_formatter):
        super(UUIDDir, self).__init__(root_path, 16, prefix_length=prefix_length, levels=levels, formatter=formatter)

    
    # TODO: refactor __check in parent to reduce required computation
    def __convert(self, key, as_hex=False):
        u = key
        if type(key) == str:
            u = uuid.UUID(key)
        elif type(key) == bytes:
            u = uuid.UUID(bytes=key)
        if as_hex:
            return u.hex
        return u.bytes


    def add(self, key, content, prefix=b''):
        key = self.__convert(key, as_hex=False)
        return super(UUIDDir, self).add(key, content, prefix=prefix)


    def key_to_string(self, k):
        return self.__convert(k, as_hex=True)


    def add_dir(self, key, content, prefix=b''):
        key = self.__convert(key, as_hex=False)
        return super(UUIDDir, self).add_dir(key, content, prefix=prefix)


    def have(self, key):
        key = self.__convert(key, as_hex=True)
        return super(UUIDDir, self).have(key)

    
    def to_filepath(self, key):
        key = self.__convert(key, as_hex=True)
        return super(UUIDDir, self).to_filepath(key)
