# standard imports
import uuid
import unittest
import tempfile
import shutil
import logging
import os

# local imports
from leveldir.uuid import UUIDDir

logging.basicConfig(level=logging.DEBUG)
logg = logging.getLogger()


class HexDirTest(unittest.TestCase):

    def setUp(self):
        self.dir = tempfile.mkdtemp() 
        self.uuiddir = UUIDDir(os.path.join(self.dir, 'q'), 3, 2)
        logg.debug('setup uuiddir root {}'.format(self.dir))
 

    def tearDown(self):
        shutil.rmtree(self.dir)
        logg.debug('cleaned hexdir root {}'.format(self.dir))


    def test_add_types(self):
        content = b'cdef'
        prefix = b'ab'
        label = uuid.uuid4()
        (c, entry_path) = self.uuiddir.add(label, content, prefix=prefix)

        label = uuid.uuid4()
        label = label.hex
        (c, entry_path) = self.uuiddir.add(label, content, prefix=prefix)

        label = uuid.uuid4()
        label = label.bytes
        (c, entry_path) = self.uuiddir.add(label, content, prefix=prefix)

        self.assertTrue(self.uuiddir.have(label))

        u = uuid.uuid4()
        (c, entry_path) = self.uuiddir.add(u, content, prefix=prefix)
        gotten_path = self.uuiddir.to_filepath(u)
        self.assertEqual(entry_path, gotten_path)

        gotten_path = self.uuiddir.to_filepath(u.bytes)
        self.assertEqual(entry_path, gotten_path)

        gotten_path = self.uuiddir.to_filepath(u.hex)
        self.assertEqual(entry_path, gotten_path)


if __name__ == '__main__':
    unittest.main()
